(create-token lease-seconds)(force-load-vault-token)Attempts to load the vault token from the config. Attempts users .vault-token file if the config has no token
Attempts to load the vault token from the config. Attempts users .vault-token file if the config has no token
(get-vault-token)(read-credentials addr)(vault-get addr & {:keys [token] :or {token (get-vault-token)}})(vault-post addr body-map & {:keys [token] :or {token (get-vault-token)}})(vault-request verb token addr args)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |